@@ -35,7 +35,7 @@ class Task:
             t.start()
         if show:
             self.update()
-            npu_print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/tasks/{1}".format(self.task_type.lower(), task_id))
+            npu_print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/task?id={1}".format(self.task_type.lower(), task_id))
 
     def wait(self):
         # if self.finished():
