@@ -1,5 +1,7 @@
 import hashlib
 import math
+import os
+
 import requests
 from bson import ObjectId
 from tqdm import tqdm
@@ -44,8 +46,10 @@ NEURO_AI_STR = f"[{bcolors.OKBLUE}Neuro Ai{bcolors.ENDC}]"
 
 def api(token_, project_name, verbosity):
     global _token
-    global  _project
+    global _project
     global VERBOSITY
+    if token_ == "":
+        token_ = os.environ.get("NPU_API_TOKEN", "")
     _token = token_
     VERBOSITY = verbosity
     if VERBOSITY != MIN_VERBOSITY:
