@@ -1,10 +1,10 @@
 from . import core, optim, loss as _loss, metrics as _metrics
 
 
-def api(token, project="Default", verbosity=1):
+def api(token="", project="Default", verbosity=1):
     """Use this function to get access to the API, providing your token. All subsequents API calls will use this token.
 
-        :param token: Token from dashboard
+        :param token: Token from dashboard. Set environment variable NPU_API_TOKEN to bypass
         :type token: str
         :param project: Project name to assign models/data/tasks to a certain project.
         :type project: str
